;; Generated package description from aggressive-completion.el  -*- no-byte-compile: t; lexical-binding:t -*-
(define-package "aggressive-completion" "1.7.0.20260527.2" "Automatic minibuffer completion" '((emacs "27.1")) :commit "5f0fd4e57f5bc9563db65cd5ba13d6c1bedf4a4a" :url "https://elpa.gnu.org/packages/aggressive-completion.html" :authors '(("Tassilo Horn" . "tsdh@gnu.org")) :maintainer '("Tassilo Horn" . "tsdh@gnu.org") :keywords '("minibuffer" "completion"))
